pub fn parse_pdx_internal(input: &'static str, desc: &str) -> BlockExpand description
Parse a string into a Block. This function is meant for use by the validator itself, to
allow it to load game description data from internal strings that are in pdx script format.