trait CharExt {
// Required methods
fn is_id_char(self) -> bool;
fn is_local_value_char(self) -> bool;
fn is_comparator_char(self) -> bool;
fn is_comparator_end_char(self) -> bool;
}Expand description
A convenience trait to add some methods to char
Required Methods
Sourcefn is_id_char(self) -> bool
fn is_id_char(self) -> bool
Can the char be part of an unquoted token?
Sourcefn is_local_value_char(self) -> bool
fn is_local_value_char(self) -> bool
Can the char be part of a reader variable name?
Sourcefn is_comparator_char(self) -> bool
fn is_comparator_char(self) -> bool
Can the char be part of a Comparator?
Sourcefn is_comparator_end_char(self) -> bool
fn is_comparator_end_char(self) -> bool
Can the char be the last charatern in a Comparator?